@@ -10,6 +10,17 @@ from reactivex.abc.disposable import DisposableBase
 from reactivex.scheduler import ThreadPoolScheduler
 from reactivex import operators
 import requests
+from .error import (
+    InvalidPIN,
+    Mail_ID_NOTFOUND,
+    Parameters
+)
+from .utils import (
+    EMAIL,
+    err_code,
+    Extension,
+    extension
+)
 author = "krypton-byte"
 logging.basicConfig(format='%(asctime)s  %(message)s', level=logging.INFO)
 log = logging.getLogger('xtempmail')
@@ -18,44 +29,6 @@ log.setLevel(logging.WARNING)
 # log.setLevel(logging.INFO)
 
 
-class Mail_ID_NOTFOUND(Exception):
-    pass
-
-
-class Parameters(Exception):
-    pass
-
-
-class InvalidPin(Exception):
-    pass
-
-
-def err_code(c: int):
-    if c == 1021:
-        return InvalidPin
-
-
-class Extension:
-    def __init__(self, ex):
-        self.ex = '@' + ex
-
-    def apply(self, text: str) -> str:
-        return f"{text}{self.ex.__str__()}"
-
-    def __repr__(self):
-        return self.ex
-
-    def __str__(self):
-        return self.ex
-
-
-extension = [Extension(i) for i in [
-    'mailto.plus', 'fexpost.com', 'fexbox.org',
-    'fexbox.ru', 'mailbox.in.ua', 'rover.info',
-    'inpwa.com', 'intopwa.com', 'tofeat.com', 'chitthi.in'
-]]
-
-
 class event:
     """
     Event Generator
@@ -89,7 +62,7 @@ class event:
             sig = signature(f)
             if sig.parameters.keys().__len__() > 1 or \
                     sig.parameters.keys().__len__() < 1:
-                raise Parameters('1 Parameters Required For Callback function')
+                raise Parameters('1 Parameters Required In Callback function')
             log.info(f'Callback Parameter: {list(sig.parameters.keys())[0]}')
             self.messages.append((
                 f,
@@ -237,7 +210,7 @@ class Email(requests.Session):
     def __init__(
         self,
         name: str,
-        ext: Extension = extension[0],
+        ext: Union[EMAIL, Extension] = EMAIL.MAILTO_PLUS,
         epin: str = ''
     ) -> None:
         super().__init__()
@@ -395,7 +368,7 @@ class Email(requests.Session):
         pool = [thread] if thread else []
         m = self.get_new_message(0)
         return reactivex.interval(interval).pipe(
-            operators.map(lambda x: m.__next__()),
+            operators.map(lambda *x: m.__next__()),
             *pool).subscribe(
                 on_next=subscribe or self.on.on_message)
 
@@ -411,7 +384,7 @@ class Email(requests.Session):
     @property
     def secret_address(self):
         if self.protected:
-            raise InvalidPin()
+            raise InvalidPIN()
         em, ex = self.get(
             'https://tempmail.plus/api/box/hidden'
             ).json()['email'].split('@')
@@ -422,13 +395,13 @@ class Email(requests.Session):
         x = self.get('https://tempmail.plus/api/mails').json()
         if x.get('err'):
             f = err_code(x['err']['code'])
-            if f == InvalidPin:
+            if f == InvalidPIN:
                 return True
         return False
 
     def Lock_Inbox(self, pin: str, duration_minutes: int = 60):
         if self.protected:
-            raise InvalidPin()
+            raise InvalidPIN()
         cp_params = self.params.copy()
         cp_params.update({
             'ttl_minutes': duration_minutes,
@@ -444,7 +417,7 @@ class Email(requests.Session):
 
     def Delete_Lock(self):
         if self.protected:
-            raise InvalidPin()
+            raise InvalidPIN()
         return self.Lock_Inbox('', 0)
 
     def __repr__(self) -> str:
